@@ -38,13 +38,29 @@ encoding_x_scale(const struct blitset* bset) {
   return bset->width;
 }
 
+// Expand NCBLIT_DEFAULT for media blitting, based on environment.
+static inline ncblitter_e 
+rgba_blitter_default(bool utf8, ncscale_e scale, bool sextants){
+  if(!utf8){
+    return NCBLIT_1x1;
+  }
+  if(scale == NCSCALE_NONE || scale == NCSCALE_SCALE){
+    return NCBLIT_2x1;
+  }
+  if(!sextants){
+    return NCBLIT_2x2;
+  }
+  return NCBLIT_3x2;
+}
+
 static inline const struct blitset*
-rgba_blitter_low(bool utf8, ncscale_e scale, bool maydegrade, ncblitter_e blitrec) {
+rgba_blitter_low(bool utf8, bool sextants, ncscale_e scale, bool maydegrade,
+                 ncblitter_e blitrec) {
   const struct blitset* bset;
   if(blitrec != NCBLIT_DEFAULT){
     bset = lookup_blitset(utf8, blitrec, maydegrade);
   }else{
-    bset = lookup_blitset(utf8, ncvisual_default_blitter(utf8, scale), maydegrade);
+    bset = lookup_blitset(utf8, rgba_blitter_default(utf8, scale, sextants), maydegrade);
   }
   if(bset && !bset->blit){ // FIXME remove this once all blitters are enabled
     bset = NULL;
@@ -58,8 +74,8 @@ static inline const struct blitset*
 rgba_blitter(const struct notcurses* nc, const struct ncvisual_options* opts) {
   const bool maydegrade = !(opts && (opts->flags & NCVISUAL_OPTION_NODEGRADE));
   const ncscale_e scale = opts ? opts->scaling : NCSCALE_NONE;
-  return rgba_blitter_low(notcurses_canutf8(nc), scale, maydegrade,
-                          opts ? opts->blitter : NCBLIT_DEFAULT);
+  return rgba_blitter_low(notcurses_canutf8(nc), notcurses_cansextant(nc),
+                          scale, maydegrade, opts ? opts->blitter : NCBLIT_DEFAULT);
 }
 
 #endif
