@@ -38,6 +38,7 @@ const char* oiio_version(void);
 #include <langinfo.h>
 #include <netinet/in.h>
 #include "notcurses/notcurses.h"
+#include "compat/compat.h"
 #include "egcpool.h"
 
 struct esctrie;
@@ -66,7 +67,7 @@ typedef struct ncplane {
   // ncplane_yx() etc. use coordinates relative to the plane to which this
   // plane is bound, but absx/absy are always relative to the terminal origin.
   // they must thus be translated by any function which moves a parent plane.
-  int absx, absy;        // origin of the plane relative to the screen
+  int absx, absy;        // origin of the plane relative to the pile's origin
   int lenx, leny;        // size of the plane, [0..len{x,y}) is addressable
   egcpool pool;          // attached storage pool for UTF-8 EGCs
   uint64_t channels;     // works the same way as cells
@@ -606,20 +607,6 @@ ncplane_cell_ref_yx(ncplane* n, int y, int x){
   return &n->fb[nfbcellidx(n, y, x)];
 }
 
-#define NANOSECS_IN_SEC 1000000000
-
-static inline uint64_t
-timespec_to_ns(const struct timespec* t){
-  return t->tv_sec * NANOSECS_IN_SEC + t->tv_nsec;
-}
-
-static inline struct timespec*
-ns_to_timespec(uint64_t ns, struct timespec* ts){
-  ts->tv_sec = ns / NANOSECS_IN_SEC;
-  ts->tv_nsec = ns % NANOSECS_IN_SEC;
-  return ts;
-}
-
 static inline void
 cell_debug(const egcpool* p, const nccell* c){
   fprintf(stderr, "gcluster: %u %s style: 0x%04x chan: 0x%016jx\n",
