@@ -69,8 +69,6 @@ notcurses_stop_minimal(void* vnc){
     if(nc->tcache.cnorm && tty_emit("cnorm", nc->tcache.cnorm, nc->ttyfd)){
       ret = -1;
     }
-  }
-  if(nc->ttyfd >= 0){
     ret |= tcsetattr(nc->ttyfd, TCSANOW, &nc->tpreserved);
   }
   return ret;
@@ -282,7 +280,7 @@ make_ncpile(notcurses* nc, ncplane* n){
 // (as once more is n).
 ncplane* ncplane_new_internal(notcurses* nc, ncplane* n,
                               const ncplane_options* nopts){
-  if(nopts->flags > NCPLANE_OPTION_HORALIGNED){
+  if(nopts->flags >= (NCPLANE_OPTION_HORALIGNED << 1u)){
     logwarn(nc, "Provided unsupported flags %016jx\n", (uintmax_t)nopts->flags);
   }
   if(nopts->rows <= 0 || nopts->cols <= 0){
@@ -632,6 +630,7 @@ int ncplane_destroy(ncplane* ncp){
     logerror(ncplane_notcurses(ncp), "Won't destroy standard plane\n");
     return -1;
   }
+//notcurses_debug(ncplane_notcurses(ncp), stderr);
   if(ncp->above){
     ncp->above->below = ncp->below;
   }else{
@@ -651,7 +650,7 @@ int ncplane_destroy(ncplane* ncp){
   struct ncplane* bound = ncp->blist;
   while(bound){
     struct ncplane* tmp = bound->bnext;
-    if(ncplane_reparent(bound, ncp->boundto) == NULL){
+    if(ncplane_reparent_family(bound, ncp->boundto) == NULL){
       ret = -1;
     }
     bound = tmp;
@@ -2149,6 +2148,23 @@ const notcurses* ncplane_notcurses_const(const ncplane* n){
   return ncplane_pile_const(n)->nc;
 }
 
+int ncplane_abs_y(const ncplane* n){
+  return n->absy; // FIXME adjust for margins?
+}
+
+int ncplane_abs_x(const ncplane* n){
+  return n->absx; // FIXME adjust for margins?
+}
+
+void ncplane_abs_yx(const ncplane* n, int* RESTRICT y, int* RESTRICT x){
+  if(y){
+    *y = ncplane_abs_y(n);
+  }
+  if(x){
+    *x = ncplane_abs_x(n);
+  }
+}
+
 ncplane* ncplane_parent(ncplane* n){
   return n->boundto;
 }
@@ -2207,6 +2223,7 @@ ncplane* ncplane_reparent(ncplane* n, ncplane* newparent){
   if(n->boundto == newparent){
     return n;
   }
+//notcurses_debug(ncplane_notcurses(n), stderr);
   if(n->blist){
     if(n->boundto == n){ // children become new root planes
       ncplane* lastlink;
@@ -2233,7 +2250,7 @@ ncplane* ncplane_reparent(ncplane* n, ncplane* newparent){
     }
     n->blist = NULL;
   }
-//notcurses_debug(ncplane_notcurses(n), stderr);
+  // FIXME would be nice to skip ncplane_descendant_p() on this call...:/
   return ncplane_reparent_family(n, newparent);
 }
 
@@ -2281,14 +2298,10 @@ ncplane* ncplane_reparent_family(ncplane* n, ncplane* newparent){
   if(ncplane_descendant_p(newparent, n)){
     return NULL;
   }
+//notcurses_debug(ncplane_notcurses(n), stderr);
   if(n->boundto == newparent){ // no-op
     return n;
   }
-  // if we are not a root plane, adjust our origin
-  if(n->boundto != n){
-    n->absx -= n->boundto->absx;
-    n->absy -= n->boundto->absy;
-  }
   if(n->bprev){ // extract from sibling list
     if( (*n->bprev = n->bnext) ){
       n->bnext->bprev = n->bprev;
@@ -2310,8 +2323,6 @@ ncplane* ncplane_reparent_family(ncplane* n, ncplane* newparent){
     pthread_mutex_unlock(&ncplane_notcurses(n)->pilelock);
     splice_zaxis_recursive(n);
   }else{ // establish ourselves as a sibling of new parent's children
-    n->absx += n->boundto->absx;
-    n->absy += n->boundto->absy;
     if( (n->bnext = newparent->blist) ){
       n->bnext->bprev = &n->bnext;
     }
@@ -2600,7 +2611,7 @@ int ncplane_putstr_yx(struct ncplane* n, int y, int x, const char* gclusters){
     y = -1;
     x = -1;
     gclusters += wcs;
-    ret += wcs;
+    ret += cols;
   }
   return ret;
 }
@@ -2618,7 +2629,7 @@ int ncplane_putstr_stained(struct ncplane* n, const char* gclusters){
       break;
     }
     gclusters += wcs;
-    ret += wcs;
+    ret += cols;
   }
   return ret;
 }
@@ -2649,11 +2660,12 @@ int ncplane_putnstr_aligned(struct ncplane* n, int y, ncalign_e align, size_t s,
 
 int ncplane_putnstr_yx(struct ncplane* n, int y, int x, size_t s, const char* gclusters){
   int ret = 0;
+  int offset = 0;
 //fprintf(stderr, "PUT %zu at %d/%d [%.*s]\n", s, y, x, (int)s, gclusters);
   // FIXME speed up this blissfully naive solution
-  while((size_t)ret < s && *gclusters){
+  while((size_t)offset < s && gclusters[offset]){
     int wcs;
-    int cols = ncplane_putegc_yx(n, y, x, gclusters, &wcs);
+    int cols = ncplane_putegc_yx(n, y, x, gclusters + offset, &wcs);
     if(cols < 0){
       return -ret;
     }
@@ -2664,8 +2676,8 @@ int ncplane_putnstr_yx(struct ncplane* n, int y, int x, size_t s, const char* gc
     // print, so that scrolling is taken into account
     y = -1;
     x = -1;
-    gclusters += wcs;
-    ret += wcs;
+    offset += wcs;
+    ret += cols;
   }
   return ret;
 }
